@@ -8,7 +8,9 @@ Usage::
     from mypy_boto3_networkmanager import (
         Client,
         DescribeGlobalNetworksPaginator,
+        GetConnectPeerAssociationsPaginator,
         GetConnectionsPaginator,
+        GetCoreNetworkChangeSetPaginator,
         GetCustomerGatewayAssociationsPaginator,
         GetDevicesPaginator,
         GetLinkAssociationsPaginator,
@@ -20,6 +22,10 @@ Usage::
         GetSitesPaginator,
         GetTransitGatewayConnectPeerAssociationsPaginator,
         GetTransitGatewayRegistrationsPaginator,
+        ListAttachmentsPaginator,
+        ListConnectPeersPaginator,
+        ListCoreNetworkPolicyVersionsPaginator,
+        ListCoreNetworksPaginator,
         NetworkManagerClient,
     )
 
@@ -29,7 +35,9 @@ Usage::
     session_client: NetworkManagerClient = session.client("networkmanager")
 
     describe_global_networks_paginator: DescribeGlobalNetworksPaginator = client.get_paginator("describe_global_networks")
+    get_connect_peer_associations_paginator: GetConnectPeerAssociationsPaginator = client.get_paginator("get_connect_peer_associations")
     get_connections_paginator: GetConnectionsPaginator = client.get_paginator("get_connections")
+    get_core_network_change_set_paginator: GetCoreNetworkChangeSetPaginator = client.get_paginator("get_core_network_change_set")
     get_customer_gateway_associations_paginator: GetCustomerGatewayAssociationsPaginator = client.get_paginator("get_customer_gateway_associations")
     get_devices_paginator: GetDevicesPaginator = client.get_paginator("get_devices")
     get_link_associations_paginator: GetLinkAssociationsPaginator = client.get_paginator("get_link_associations")
@@ -41,12 +49,18 @@ Usage::
     get_sites_paginator: GetSitesPaginator = client.get_paginator("get_sites")
     get_transit_gateway_connect_peer_associations_paginator: GetTransitGatewayConnectPeerAssociationsPaginator = client.get_paginator("get_transit_gateway_connect_peer_associations")
     get_transit_gateway_registrations_paginator: GetTransitGatewayRegistrationsPaginator = client.get_paginator("get_transit_gateway_registrations")
+    list_attachments_paginator: ListAttachmentsPaginator = client.get_paginator("list_attachments")
+    list_connect_peers_paginator: ListConnectPeersPaginator = client.get_paginator("list_connect_peers")
+    list_core_network_policy_versions_paginator: ListCoreNetworkPolicyVersionsPaginator = client.get_paginator("list_core_network_policy_versions")
+    list_core_networks_paginator: ListCoreNetworksPaginator = client.get_paginator("list_core_networks")
     ```
 """
 from .client import NetworkManagerClient
 from .paginator import (
     DescribeGlobalNetworksPaginator,
     GetConnectionsPaginator,
+    GetConnectPeerAssociationsPaginator,
+    GetCoreNetworkChangeSetPaginator,
     GetCustomerGatewayAssociationsPaginator,
     GetDevicesPaginator,
     GetLinkAssociationsPaginator,
@@ -58,6 +72,10 @@ from .paginator import (
     GetSitesPaginator,
     GetTransitGatewayConnectPeerAssociationsPaginator,
     GetTransitGatewayRegistrationsPaginator,
+    ListAttachmentsPaginator,
+    ListConnectPeersPaginator,
+    ListCoreNetworkPolicyVersionsPaginator,
+    ListCoreNetworksPaginator,
 )
 
 Client = NetworkManagerClient
@@ -66,7 +84,9 @@ Client = NetworkManagerClient
 __all__ = (
     "Client",
     "DescribeGlobalNetworksPaginator",
+    "GetConnectPeerAssociationsPaginator",
     "GetConnectionsPaginator",
+    "GetCoreNetworkChangeSetPaginator",
     "GetCustomerGatewayAssociationsPaginator",
     "GetDevicesPaginator",
     "GetLinkAssociationsPaginator",
@@ -78,5 +98,9 @@ __all__ = (
     "GetSitesPaginator",
     "GetTransitGatewayConnectPeerAssociationsPaginator",
     "GetTransitGatewayRegistrationsPaginator",
+    "ListAttachmentsPaginator",
+    "ListConnectPeersPaginator",
+    "ListCoreNetworkPolicyVersionsPaginator",
+    "ListCoreNetworksPaginator",
     "NetworkManagerClient",
 )
