@@ -6,9 +6,9 @@ Type annotations for networkmanager service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_networkmanager.literals import ConnectionStateType
+    from mypy_boto3_networkmanager.literals import AttachmentStateType
 
-    data: ConnectionStateType = "AVAILABLE"
+    data: AttachmentStateType = "AVAILABLE"
     ```
 """
 import sys
@@ -20,13 +20,24 @@ else:
 
 
 __all__ = (
+    "AttachmentStateType",
+    "AttachmentTypeType",
+    "ChangeActionType",
+    "ChangeSetStateType",
+    "ChangeTypeType",
+    "ConnectPeerAssociationStateType",
+    "ConnectPeerStateType",
     "ConnectionStateType",
     "ConnectionStatusType",
     "ConnectionTypeType",
+    "CoreNetworkPolicyAliasType",
+    "CoreNetworkStateType",
     "CustomerGatewayAssociationStateType",
     "DescribeGlobalNetworksPaginatorName",
     "DeviceStateType",
+    "GetConnectPeerAssociationsPaginatorName",
     "GetConnectionsPaginatorName",
+    "GetCoreNetworkChangeSetPaginatorName",
     "GetCustomerGatewayAssociationsPaginatorName",
     "GetDevicesPaginatorName",
     "GetLinkAssociationsPaginatorName",
@@ -41,6 +52,10 @@ __all__ = (
     "GlobalNetworkStateType",
     "LinkAssociationStateType",
     "LinkStateType",
+    "ListAttachmentsPaginatorName",
+    "ListConnectPeersPaginatorName",
+    "ListCoreNetworkPolicyVersionsPaginatorName",
+    "ListCoreNetworksPaginatorName",
     "RouteAnalysisCompletionReasonCodeType",
     "RouteAnalysisCompletionResultCodeType",
     "RouteAnalysisStatusType",
@@ -50,18 +65,53 @@ __all__ = (
     "SiteStateType",
     "TransitGatewayConnectPeerAssociationStateType",
     "TransitGatewayRegistrationStateType",
+    "TunnelProtocolType",
     "ServiceName",
     "PaginatorName",
 )
 
 
+AttachmentStateType = Literal[
+    "AVAILABLE",
+    "CREATING",
+    "DELETING",
+    "FAILED",
+    "PENDING_ATTACHMENT_ACCEPTANCE",
+    "PENDING_NETWORK_UPDATE",
+    "PENDING_TAG_ACCEPTANCE",
+    "REJECTED",
+    "UPDATING",
+]
+AttachmentTypeType = Literal["CONNECT", "SITE_TO_SITE_VPN", "VPC"]
+ChangeActionType = Literal["ADD", "MODIFY", "REMOVE"]
+ChangeSetStateType = Literal[
+    "EXECUTING",
+    "EXECUTION_SUCCEEDED",
+    "FAILED_GENERATION",
+    "OUT_OF_DATE",
+    "PENDING_GENERATION",
+    "READY_TO_EXECUTE",
+]
+ChangeTypeType = Literal[
+    "ATTACHMENT_MAPPING",
+    "ATTACHMENT_ROUTE_PROPAGATION",
+    "ATTACHMENT_ROUTE_STATIC",
+    "CORE_NETWORK_EDGE",
+    "CORE_NETWORK_SEGMENT",
+]
+ConnectPeerAssociationStateType = Literal["AVAILABLE", "DELETED", "DELETING", "PENDING"]
+ConnectPeerStateType = Literal["AVAILABLE", "CREATING", "DELETING", "FAILED"]
 ConnectionStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
 ConnectionStatusType = Literal["DOWN", "UP"]
 ConnectionTypeType = Literal["BGP", "IPSEC"]
+CoreNetworkPolicyAliasType = Literal["LATEST", "LIVE"]
+CoreNetworkStateType = Literal["AVAILABLE", "CREATING", "DELETING", "UPDATING"]
 CustomerGatewayAssociationStateType = Literal["AVAILABLE", "DELETED", "DELETING", "PENDING"]
 DescribeGlobalNetworksPaginatorName = Literal["describe_global_networks"]
 DeviceStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
+GetConnectPeerAssociationsPaginatorName = Literal["get_connect_peer_associations"]
 GetConnectionsPaginatorName = Literal["get_connections"]
+GetCoreNetworkChangeSetPaginatorName = Literal["get_core_network_change_set"]
 GetCustomerGatewayAssociationsPaginatorName = Literal["get_customer_gateway_associations"]
 GetDevicesPaginatorName = Literal["get_devices"]
 GetLinkAssociationsPaginatorName = Literal["get_link_associations"]
@@ -78,6 +128,10 @@ GetTransitGatewayRegistrationsPaginatorName = Literal["get_transit_gateway_regis
 GlobalNetworkStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
 LinkAssociationStateType = Literal["AVAILABLE", "DELETED", "DELETING", "PENDING"]
 LinkStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
+ListAttachmentsPaginatorName = Literal["list_attachments"]
+ListConnectPeersPaginatorName = Literal["list_connect_peers"]
+ListCoreNetworkPolicyVersionsPaginatorName = Literal["list_core_network_policy_versions"]
+ListCoreNetworksPaginatorName = Literal["list_core_networks"]
 RouteAnalysisCompletionReasonCodeType = Literal[
     "BLACKHOLE_ROUTE_FOR_DESTINATION_FOUND",
     "CYCLIC_PATH_DETECTED",
@@ -94,7 +148,7 @@ RouteAnalysisCompletionReasonCodeType = Literal[
 RouteAnalysisCompletionResultCodeType = Literal["CONNECTED", "NOT_CONNECTED"]
 RouteAnalysisStatusType = Literal["COMPLETED", "FAILED", "RUNNING"]
 RouteStateType = Literal["ACTIVE", "BLACKHOLE"]
-RouteTableTypeType = Literal["TRANSIT_GATEWAY_ROUTE_TABLE"]
+RouteTableTypeType = Literal["CORE_NETWORK_SEGMENT", "TRANSIT_GATEWAY_ROUTE_TABLE"]
 RouteTypeType = Literal["PROPAGATED", "STATIC"]
 SiteStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
 TransitGatewayConnectPeerAssociationStateType = Literal[
@@ -103,6 +157,7 @@ TransitGatewayConnectPeerAssociationStateType = Literal[
 TransitGatewayRegistrationStateType = Literal[
     "AVAILABLE", "DELETED", "DELETING", "FAILED", "PENDING"
 ]
+TunnelProtocolType = Literal["GRE"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -112,10 +167,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -130,6 +187,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -184,6 +242,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -205,6 +264,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -231,6 +291,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -244,6 +305,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -289,7 +351,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -318,11 +382,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -332,6 +398,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -389,11 +456,14 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
 PaginatorName = Literal[
     "describe_global_networks",
+    "get_connect_peer_associations",
     "get_connections",
+    "get_core_network_change_set",
     "get_customer_gateway_associations",
     "get_devices",
     "get_link_associations",
@@ -405,4 +475,8 @@ PaginatorName = Literal[
     "get_sites",
     "get_transit_gateway_connect_peer_associations",
     "get_transit_gateway_registrations",
+    "list_attachments",
+    "list_connect_peers",
+    "list_core_network_policy_versions",
+    "list_core_networks",
 ]
